@@ -10,18 +10,18 @@ XML::GrammarBase::Role::RelaxNG - base class for a RelaxNG validator
 
 =head1 VERSION
 
-Version 0.2.1
+Version 0.2.2
 
 =cut
 
 use MooX::Role 'late';
 
 use File::ShareDir qw(dist_dir);
-use XML::LibXML;
+use XML::LibXML '2.0017';
 
 with ('XML::GrammarBase::Role::DataDir');
 
-our $VERSION = '0.2.1';
+our $VERSION = '0.2.2';
 
 has 'rng_schema_basename' => (isa => 'Str', is => 'rw');
 has '_rng' =>
